# -*- coding: utf-8 -*-
from setuphelpers import *
import requests, platform
import bs4 as BeautifulSoup


bin_name_string = "wireguard-amd64-%s.msi"


def update_package():
    print("Download/Update package content from upstream binary sources")

    result = False
    proxies = get_proxies()

    if not proxies:
        proxies = get_proxies_from_wapt_console()
    # Specific app values
    app_name = control.name
    url = "https://github.com/WireGuard/wireguard-windows/tags"

    # Getting latest version from official website
    
    bs_search = bs_find(url, "h2", "class", "f4 d-inline")
    version = ((bs_search.findNext())["href"].split("/")[-1]).replace("v", "")

    latest_bin = bin_name_string % version
    url_dl = "https://download.wireguard.com/windows-client/" + latest_bin

    print("Latest " + app_name + " version is: " + version)
    print("Download url is: " + url_dl)

    # Downloading latest binaries
    if not isfile(latest_bin):
        print("Downloading: " + latest_bin)
        wget(url_dl, latest_bin, proxies=proxies)

        # Get version from file
        version_from_file = get_msi_properties(latest_bin)["ProductVersion"]
        if version != version_from_file and version_from_file != "":
            version = version_from_file
            old_latest_bin = latest_bin
            latest_bin = bin_name_string % version
            if isfile(latest_bin):
                remove_file(latest_bin)
            os.rename(old_latest_bin, latest_bin)

        # Change version of the package
        control.version = "%s-%s" % (version, int(control.version.split("-", 1)[1]) + 1)
        control.save_control_to_wapt(".")
        print("Changing version to " + control.version + " in WAPT\\control")
        print("Update package done. You can now build-upload your package")
    else:
        print("This package is already up-to-date")

    # Deleting outdated binaries
    for bin_in_dir in glob.glob("*.exe") or glob.glob("*.msi"):
        if bin_in_dir != latest_bin:
            print("Outdated binary: " + bin_in_dir + " Deleted")
            remove_file(bin_in_dir)
